@@ -51,6 +51,7 @@ def pytest_configure(config):
         config._flake8showshource = config.getini("flake8-show-source")
         config._flake8statistics = config.getini("flake8-statistics")
         config._flake8exts = config.getini("flake8-extensions")
+        config.addinivalue_line('markers', "flake8: Tests which run flake8.")
         if hasattr(config, 'cache'):
             config._flake8mtimes = config.cache.get(HISTKEY, {})
 
@@ -155,7 +156,7 @@ class Ignorer:
             ignores.append((glob, ign))
 
     def __call__(self, path):
-        l = []
+        l = []  # noqa: E741
         for (glob, ignlist) in self.ignores:
             if not glob or path.fnmatch(glob):
                 if ignlist is None:
@@ -177,10 +178,12 @@ def check_file(path, flake8ignore, maxlength, maxcomplexity,
     if statistics:
         args += ['--statistics']
     app = application.Application()
+    app.parse_preliminary_options_and_args(args)
+    app.make_config_finder()
     app.find_plugins()
     app.register_plugin_options()
     app.parse_configuration_and_cli(args)
-    app.options.ignore = flake8ignore
+    app.options.ignore.extend(flake8ignore)
     app.make_formatter()  # fix this
     app.make_notifier()
     app.make_guide()
